@@ -1,5 +1,5 @@
 from django.contrib import admin
-from models import Banner
+from banners.models import Banner
 # Add your admin site registrations here, eg.
 # from banners.models import Author
 admin.site.register(Banner)
