@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
 
 from django.db import models
-from tagging.fields import TagField
+from taggit.managers import TaggableManager
 from django.template.loader import render_to_string
 from django.template.defaultfilters import slugify
 from django.template import Context, Template
 
 class Banner(models.Model):
     code = models.TextField(max_length=1024, blank=True, null=True)
-    slot = TagField()
+    slot = TaggableManager()
     clicks = models.PositiveIntegerField(default=0, blank=True)
     views = models.PositiveIntegerField(default=0, blank=True)
 
