@@ -6,7 +6,7 @@ register = template.Library()
 @register.inclusion_tag('single.html')
 def pop_slot(slot):
     banner=None
-    banners = Banner.objects.filter(slot=slot)
+    banners = Banner.objects.filter(slot__name=slot)
     if banners:
         banner = choice(banners)
     return {'banner':banner}
@@ -14,7 +14,7 @@ def pop_slot(slot):
 @register.inclusion_tag('slot.html')
 def lookup_banners(slot):
     try :
-        banners = Banner.objects.filter(slot__contains=slot)
+        banners = Banner.objects.filter(slot__name__contains=slot)
     except Banner.DoesNotExists:
         banners=None
     return {'banners':banners}
